%{ Generic code to handle a staff in a typical LHML score.

The staff can have up to 4 lyrics associated.

Variables used:

 \thisStaff	the id of this staff, e.g., "high" or "lead"
 \global	(optional) global settings (clef, key, ...)

For the following variables, 'xxx' denotes the id as specified with
\thisStaff. All variables are optional. If they have not been defined
in the source the corresponding part is omitted.

In particular, if \xxxMusic is not defined, nothing is produced for
this staff.

 \xxxMusic	the music (where xxx = \thisStaff)
 \xxxName	instrument name, e.g., "Chords "
 \xxxInstrument	midi instrument, e.g., "acoustic grand"
 \xxxWords	lyrics
 \xxxAWords	more lyrics
 \xxxBWords	more lyrics
 \xxxCWords	more lyrics
 \xxxDWords	more lyrics

For a typical case, this boils down to:

  \new Staff = HighStaff <<
     \new Voice = HighVoice {
       \set Staff.instrumentName = \highName
       \set Staff.midiInstrument = "acoustic grand"
       \global
       \highMusic
     }
     \lyricsto HighVoice \highWords
     \lyricsto HighVoice \highAWords
     \lyricsto HighVoice \highBWords
     \lyricsto HighVoice \highCWords
     \lyricsto HighVoice \highDWords
  >>

%}

% Produces a symbol for a "foo" + "Bar".
#(define-public (thisSym name)
  (string->symbol (string-append thisStaff name)))

% We cannot use scheme for Staff = ..., so define variables.
#(define-public staffName
  (string-capitalize (string-append thisStaff "Staff")))
#(define-public voiceName
  (string-capitalize (string-append thisStaff "Voice")))

% Check for \xxxMusic. The complete staff code will be omitted if this
% is not defined.
\ifDefinedThen #(thisSym "Music")
  \new Staff = \staffName <<
    \new Voice = \voiceName {

      % Set instrument and midiInstrument if the corresponding
      % variables have been defined, or use a suitable default value
      % otherwise.
      \set Staff.instrumentName = 
	#(if (defined? (thisSym "Name"))
	  (primitive-eval (thisSym "Name"))
	  "")
      \set Staff.midiInstrument = 
	#(if (defined? (thisSym "Instrument"))
	  (primitive-eval (thisSym "Instrument"))
	  "acoustic grand")

      % Global settings.
      \ifDefined #'global

      % The music.
      \ifDefined #(thisSym "Music")
    }

    % Add lyrics if requestes.
    \ifDefinedThen #(thisSym "Words")   \lyricsto \voiceName \ifDefined #(thisSym "Words")
    \ifDefinedThen #(thisSym "AWords")  \lyricsto \voiceName \ifDefined #(thisSym "AWords")
    \ifDefinedThen #(thisSym "BWords")  \lyricsto \voiceName \ifDefined #(thisSym "BWords")
    \ifDefinedThen #(thisSym "CWords")  \lyricsto \voiceName \ifDefined #(thisSym "CWords")
  >>

